<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
     <title>Архив %(listname)s, том %(archive)s, сообщения упорядочены по %(archtype)s</title>
     <META NAME="robots" CONTENT="noindex,follow">
     %(encoding)s
  </HEAD>
  <BODY BGCOLOR="#ffffff">
      <a name="start"></A>
      <h1>Том %(archive)s, сообщения упорядочены по %(archtype)s</h1>
      <ul>
         <li> <b>Сортировать по:</b>
                %(thread_ref)s
                %(subject_ref)s
                %(author_ref)s
                %(date_ref)s

             <li><b><a href="%(listinfo)s">Подробная информация о списке рассылки...</a></b></li>
      </ul>
      <p><b>Первое сообщение:</b> <i>%(firstdate)s</i><br>
         <b>Последнее сообщение:</b> <i>%(lastdate)s</i><br>
         <b>Сообщений:</b> %(size)s<p>
     <ul>
