<!-- $Revision: 4565 $ -->
<html>
<head><title><MM-List-Name> V&yacute;sledky pøihl&aacute;&scaron;en&iacute;</title></head>
<body bgcolor="white">
<h1><MM-List-Name> V&yacute;sledky pøihl&aacute;&scaron;en&iacute;</h1>
<MM-Results>
<MM-Mailman-Footer>
</body>
</html>
