<!-- $Revision: 7198 $ -->
<html>
<head><title>Resultados de inscri&ccedil;&atilde;o na lista <MM-List-Name></title></head>
<body bgcolor="white">
<h1><MM-List-Name> Resultados de inscri&ccedil;&atilde;o</h1>
<MM-Results>
<MM-Mailman-Footer>
</body>
</html>
